@@ -9,7 +9,8 @@ from tesseract_olap.common import BaseError
 
 
 class BackendError(BaseError):
-    """Base class for exceptions in this module."""
+    """Base class for exceptions in `tesseract_olap.backend` module."""
+    code = 500
 
 
 class BackendNotReadyError(BackendError):
@@ -31,9 +32,21 @@ class UpstreamInternalError(BackendError):
     """
 
 
-class InvalidAggregatorError(BackendError):
-    """This error occurs when a Measure was configured with an Aggregator
-    function unsupported by the current backend.
+class UnexpectedResponseError(BackendError):
+    """This error occurs when the response sent by the remote server doesn't
+    adjust to the expected shape, and the database driver has problems to handle
+    it.
 
-    This must be reported to the administrator, but also should stop the process.
+    This must be caught and logged, but usually is related to a malformed query,
+    so not further handling might be needed.
+    """
+    code = 400
+
+
+class BackendValidationError(BackendError):
+    """This error occurs when the schema is configured to use certain features
+    that the backend server, or the backend module, is not prepared to handle.
+
+    This must be reported to the administrator, but also should stop the process
+    so the user can fix the schema.
     """
