@@ -108,6 +108,7 @@ class CubeTraverser:
 
     _cube: "Cube"
     _dimension_map: Mapping[str, "DimensionTraverser"]
+    _table: Union["Table", "InlineTable"]
 
     def __init__(
         self,
@@ -125,6 +126,9 @@ class CubeTraverser:
                        table_map=table_map))
             for name, item in cube.dimension_map.items()
         )
+        self._table = table_map[cube.table] \
+                      if isinstance(cube.table, str) else \
+                      cube.table
 
     def __repr__(self) -> str:
         return f"CubeTraverser(name='{self._cube.name}', table={self.table})"
@@ -142,8 +146,8 @@ class CubeTraverser:
         return self._cube.captions
 
     @property
-    def table(self) -> Table:
-        return self._cube.table
+    def table(self) -> Union["Table", "InlineTable"]:
+        return self._table
 
     @property
     def measures(self) -> Iterable["Measure"]:
@@ -398,12 +402,9 @@ class DimensionTraverser(EntityUsageTraverser[Dimension, DimensionUsage]):
             )
         else:
             self.hierarchy_map = OrderedDict(
-                (
-                    name,
-                    HierarchyTraverser(
-                        entity.hierarchy_map[item.source], item, table_map=table_map
-                    ),
-                )
+                (name, HierarchyTraverser(
+                    entity.hierarchy_map[item.source], item, table_map=table_map
+                ))
                 for name, item in usage.hierarchy_map.items()
             )
 
@@ -484,6 +485,7 @@ class HierarchyTraverser(EntityUsageTraverser[Hierarchy, HierarchyUsage]):
 
     level_map: Mapping[str, "LevelTraverser"]
     primary_key: str
+    # `table` might be `None` if intended to use foreign key as value, like "Year"
     table: Union["Table", "InlineTable", None]
 
     def __init__(
@@ -519,6 +521,19 @@ class HierarchyTraverser(EntityUsageTraverser[Hierarchy, HierarchyUsage]):
         """Returns a generator that yields all Properties under this Hierarchy."""
         return chain(*(item.properties for item in self.levels))
 
+    @property
+    def default_member(self):
+        """Returns a tuple containing a Level and a default member ID, to restrict
+        the data used in queries.
+        """
+        if self._entity.default_member is None:
+            return None
+
+        level_name, member = self._entity.default_member
+        level = self.get_level(level_name)
+        caster = level.key_type.get_caster()
+        return level, caster(member)
+
     def get_level(self, name: str) -> "LevelTraverser":
         """Retrieves a Level from this Cube by its name."""
         try:
@@ -549,6 +564,7 @@ class LevelTraverser(EntityUsageTraverser[Level, LevelUsage]):
     depth: int
     key_column: str
     key_type: MemberType
+    name: str
     property_map: Mapping[str, "PropertyTraverser"]
 
     def __init__(self, entity: "Level", usage: Optional["LevelUsage"] = None):
